<?php
/*
Plugin Name: Lightbox Gallery
Plugin URI: http://wordpressgogo.com/development/lightbox-gallery.html
Description: Changes to the lightbox view in galleries.
Author: Hiroaki Miyashita
Version: 0.2
Author URI: http://wordpressgogo.com/
*/

add_action('init', 'lightbox_gallery_textdomain');
function lightbox_gallery_textdomain() {
	load_plugin_textdomain('lightbox-gallery', 'wp-content/plugins/lightbox-gallery');
}

add_action('wp_head', 'add_lightbox_gallery_head',1);
add_action('wp_print_scripts', 'add_lightbox_gallery_jquery',1);

function add_lightbox_gallery_head() {
	echo '<link rel="stylesheet" type="text/css" href="' . get_settings('siteurl') . '/wp-content/plugins/lightbox-gallery/lightbox-gallery.css" />'."\n";
	echo '<link rel="stylesheet" type="text/css" href="' . get_settings('siteurl') . '/wp-content/plugins/lightbox-gallery/js/jquery.lightbox.css" />'."\n";
	echo '<link rel="stylesheet" type="text/css" href="' . get_settings('siteurl') . '/wp-content/plugins/lightbox-gallery/js/jquery.tooltip.css" />'."\n";
}
	
function add_lightbox_gallery_jquery() {
	if (strpos($_SERVER['REQUEST_URI'], 'admin.php') === false ) {
		wp_enqueue_script( 'jquery');
		wp_enqueue_script('dimensions', '/wp-includes/js/jquery/jquery.dimensions.js', array('jquery'));
		wp_enqueue_script('bgtiframe', '/wp-content/plugins/lightbox-gallery/js/jquery.bgiframe.js', array('jquery'));
		wp_enqueue_script('lightbox', '/wp-content/plugins/lightbox-gallery/js/jquery.lightbox.js', array('jquery'));
		wp_enqueue_script('tooltip', '/wp-content/plugins/lightbox-gallery/js/jquery.tooltip.js', array('jquery'));
		wp_enqueue_script('lightbox-gallery', '/wp-content/plugins/lightbox-gallery/lightbox-gallery.js', array('jquery'));
	}
}

add_shortcode('gallery', 'lightbox_gallery');

function lightbox_gallery($attr) {
	global $post;

	// Allow plugins/themes to override the default gallery template.
	$output = apply_filters('post_gallery', '', $attr);
	if ( $output != '' )
		return $output;
		
	extract(shortcode_atts(array(
		'orderby'    => 'ID ASC',
		'id'         => $post->ID,
		'itemtag'    => 'dl',
		'icontag'    => 'dt',
		'captiontag' => 'dd',
		'columns'    => 3,
		'size'       => 'thumbnail',
		'lightboxsize' => 'medium',
		'meta'       => 'false'
	), $attr));
	
	$id = intval($id);
	$orderby = addslashes($orderby);
	$attachments = get_children("post_parent=$id&post_type=attachment&post_mime_type=image&orderby=\"{$orderby}\"");

	if ( empty($attachments) )
		return '';

	if ( is_feed() ) {
		$output = "\n";
		foreach ( $attachments as $id => $attachment )
			$output .= wp_get_attachment_link($id, $size, true) . "\n";
		return $output;
	}

	$listtag = tag_escape($listtag);
	$itemtag = tag_escape($itemtag);
	$captiontag = tag_escape($captiontag);
	$columns = intval($columns);
	$itemwidth = $columns > 0 ? floor(100/$columns) : 100;
	
	$output = apply_filters('gallery_style', "
<style type='text/css'>
	.gallery-item {width: {$itemwidth}%;}
</style>
<div class='gallery'>");

	foreach ( $attachments as $id => $attachment ) {
		$thumbnail_link = wp_get_attachment_image_src($attachment->ID, $size, false);
		$lightbox_link = wp_get_attachment_image_src($attachment->ID, $lightboxsize, false);
		trim($attachment->post_content);
		trim($attachment->post_excerpt);
		
		if($meta == "true") {
			$imagedata = wp_get_attachment_metadata($attachment->ID);
			unset($metadata);
			if($imagedata['image_meta']['camera'])
				$metadata .= __('camera', 'lightbox-gallery')            . ": ". $imagedata['image_meta']['camera'] . " ";
			if($imagedata['image_meta']['aperture'])
				$metadata .= __('aperture', 'lightbox-gallery')          . ": F". $imagedata['image_meta']['aperture'] . " ";
			if($imagedata['image_meta']['focal_length'])
				$metadata .= __('focal_length', 'lightbox-gallery')      . ": ". $imagedata['image_meta']['focal_length'] . "mm ";
			if($imagedata['image_meta']['shutter_speed']) {
				if($imagedata['image_meta']['shutter_speed']<1) $speed = "1/". round(1/$imagedata['image_meta']['shutter_speed']);
				else $speed = $imagedata['image_meta']['shutter_speed'];
				$metadata .= __('shutter_speed', 'lightbox-gallery')     . ": " . $speed . " ";
			}
			if($imagedata['image_meta']['created_timestamp'])
				$metadata .= __('created_timestamp', 'lightbox-gallery') . ": ". date('Y:m:d H:i:s', $imagedata['image_meta']['created_timestamp']);
		}

		$output .= "<{$itemtag} class='gallery-item'>";
		$output .= "
<{$icontag} class='gallery-icon'>
<a href='{$lightbox_link[0]}' title='{$attachment->post_excerpt}'><img src='{$thumbnail_link[0]}' width='{$thumbnail_link[1]}' height='{$thumbnail_link[2]}' alt='{$attachment->post_excerpt}' /></a>
</{$icontag}>";
		if ( $captiontag && (trim($attachment->post_excerpt) || trim($attachment->post_content) || $metadata) ) {
			$output .= "<{$captiontag} class='gallery-caption'>";
if($attachment->post_excerpt) $output .= $attachment->post_excerpt . "<br />\n";
if($attachment->post_content) $output .= $attachment->post_content . "<br />\n";
if($metadata) $output .= $metadata;
			$output .= "</{$captiontag}>";
		}
		$output .= "</{$itemtag}>";
		if ( $columns > 0 && ++$i % $columns == 0 )
			$output .= '<div style="clear: both"></div>';
	}

	$output .= '
<div style="clear: both"></div>
</div>';

	return $output;
}


?>